#
# spec file for package gphoto
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gphoto
BuildRequires:  cdk-devel
BuildRequires:  libgphoto2-devel >= 2.5.17
BuildRequires:  libjpeg-devel
BuildRequires:  pkg-config
BuildRequires:  popt-devel
BuildRequires:  readline-devel
URL:            https://gphoto.sourceforge.io/
Summary:        A Digital Camera Utility
License:        GPL-2.0-or-later
Group:          Hardware/Camera
Version:        2.5.28
Release:        2.13
Source0:        https://downloads.sourceforge.net/project/gphoto/gphoto/%{version}/%{name}2-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/project/gphoto/gphoto/%{version}/%{name}2-%{version}.tar.xz.asc
Source2:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
gPhoto (GNU Photo) is a command line tool for previewing, retrieving,
and capturing images from a range of supported digital cameras to your
local hard drive. It does not support digital cameras based on the USB
storage protocol, because those can be mounted by Linux directly. Find
the list of supported cameras at the following URL:

https://gphoto.sourceforge.io/proj/libgphoto2/support.php

or by running

gphoto2 --list-cameras

%prep
%setup -q -n gphoto2-%{version}

%build
pkg-config --libs libgphoto2
export CFLAGS="$RPM_OPT_FLAGS -fPIE"
export LDFLAGS="-pie"
%configure	\
  --with-cdk-prefix=/usr		\
  --with-doc-dir=%{_defaultdocdir}/%{name}
make

%check
make check

%install
make DESTDIR=$RPM_BUILD_ROOT mandir=%{_mandir} install
mkdir -p $RPM_BUILD_ROOT/%{_defaultdocdir}/%{name}
mv $RPM_BUILD_ROOT/usr/share/doc/gphoto2/* $RPM_BUILD_ROOT/%{_defaultdocdir}/%{name}
%find_lang %{name}2

%files -f %{name}2.lang
%defattr(-,root,root)
%{_defaultdocdir}/%{name}
%{_prefix}/bin/gphoto2
%{_mandir}/man1/gphoto2.1*

%changelog
* Tue Apr 19 2022 Marcus Meissner <meissner@suse.com>
- use https urls
* Mon Jan  3 2022 Marcus Meissner <meissner@suse.com>
- updated to 2.5.28 release
  * show-preview: fixed to be a moving picture by using explicit memory based file
  * --parsable: new option for listing files in parsable form
  * --filenumber FILENUMBER: new option to allow --filename %%n start at another number than 1.
  * wait-event: sending SIGUSR1 signal to gphoto2 during a running --wait-event / --capture-tethered will trigger image capture
  * ctrl-c also now cancels multi-file actions
  * translations: updated german
* Sun Feb 21 2021 Marcus Meissner <meissner@suse.com>
- updated to 2.5.27 release
  * fixed cdk detection
  * adjust range detection for filenames containing or starting with -
* Sun Oct 11 2020 Marcus Meissner <meissner@suse.com>
- updated to 2.5.26 release
  * movie capture: allow some busy results before terminating
  * wait-event/capture-tethered: allow terminating with SIGUSR2, granularity 1 second
  * wait-event: allow waiting for TIMEOUT
- upstreamed fix-exif.patch
* Sun May 31 2020 Marcus Meissner <meissner@suse.com>
- fix-exif.patch: fix build with exif 0.6.22, which spells FlashPixversion
  now FlashpixVersion
* Sun Jun  2 2019 Marcus Meissner <meissner@suse.com>
- updated to 2.5.23 release
  - bugfixes
* Sat Oct 27 2018 meissner@suse.com
- updated to 2.5.20 release
  * maximum number in file ranges bumped from 16384 to 65536
  * add shell commands to match commandline: summary, storage-info, trigger-capture
  * fixed a fd leak
  * translations: updated simplified chinese
* Mon Apr 16 2018 meissner@suse.com
- updated to 2.5.17 release
  * report new GP_EVENT_FILE_CHANGED event
  * some bugfixes
* Fri Oct  6 2017 meissner@suse.com
- updated to 2.5.15 release
  * In the config getters, print out the Readonly flag and also an END marker
  * Fixed "now" timesetting also for set-config-value
* Mon Jun  5 2017 meissner@suse.com
- updated to 2.5.14 release
  * translation updates: french, esperanto
  * some bugfixes
* Sun Nov 20 2016 meissner@suse.com
- updated to 2.5.11 release
  * some errors result in exit 0, where it should have been an error exit
  * some windows bugfixes
  * translation updates: icelandic
* Wed Mar 23 2016 meissner@suse.com
- updated to 2.5.10 release
  * use new single configuration set/get if possible
  * updated translations: serbian, russian, hungarian, vietnamese, ukrainian, polish, swedish, brazilian portuguese
  * require libgphoto2 2.5.10 or newer
* Wed Nov 18 2015 meissner@suse.com
- updated to 2.5.9 release
  Now maintained (source and issue tracker) in GIT at https://github.com/gphoto/gphoto2
  * Added testcamera.pl, a tool for testing attached cameras with gphoto2.
  * fixed some bugs
  * report trigger capture in --ability
  * capture-preview can honor filename and prefixes
  * updated translations: french, ukrainian, vietnamese, polish, russian, italian
* Sun Jul  5 2015 meissner@suse.com
- updated to 2.5.8 release
  * --keep-raw option added, which leaves non-JPEG files on camera during
    capture or wait-event-and-download
  * --show-preview option split out of --capture-preview. --show-preview
    now displays the ascii art preview, --capture-preview no longer does.
  * updated translations: french, ukrainian, vietnamese, russian, polish,
    dutch, hungarian, esperanto, serbian, danish
- updated gphoto2.keyring to use my new key
* Mon Dec 22 2014 meissner@suse.com
- updated to 2.5.6 release
  wait-event can now match on strings
  translations updates
  do not use trigger capture in multi-frame capture
* Sun Nov 16 2014 meissner@suse.com
- remove gpg-offline usage, now checked by source services.
* Sun Aug 17 2014 meissner@suse.com
- updated to 2.5.5 release
  manpage updated
  updated translations
  bugfix for DST usage in handling date/time widgets
  adjusted wait time heuristics after capture
  - -debug-loglevel=(debug|verbose|data|all) option added to select debug verbosity
  fixed --filename with cross-device usage
* Sun Mar 23 2014 meissner@suse.com
- updated to 2.5.4 release
  - --skip-existing option that skips if a local file would already exist
  - %%F for foldername inclusion added to format strings for --filename
  - add the commandline arguments to the debug log
* Mon Jan 13 2014 meissner@suse.com
- updated to 2.5.3 final
  - --show-exif bugfix
  - translations updates
- make check
* Sun May  5 2013 meissner@suse.com
- updated to 2.5.2 final
  * new --reset option to reset usb devices.
  * using --filename, if the camera reports 1. Jan 1970, fall back to
    use the current date/time.
  * translations updated: french, polish, vietnamese, russian, simplified chinese, danish
- gpg tarball checking
* Sun Jan 27 2013 meissner@suse.com
- updated to 2.5.1 final
  - timing bugfixes after capture
* Wed Jan  9 2013 meissner@suse.com
- updated to 2.5.0.2 temp snapshot
  * Fixed that the meaning of --keep and --no-keep was switched.
  * Allow passing absolute filenames to
  - p, -d, -r/--rmdir, -m/--mkdir, -t, --show-info, --get-metadata,
  - -get-raw-data, --get-audio-data,
  like e.g.:
  gphoto2 -p /store_00010001/DCIM/100D7000/DSC_0001.JPG
  * -L --quiet  now prints a list of all files, 1 per line.
  * -l --quiet  now prints a list of all folders, 1 per line.
* Thu Sep 13 2012 meissner@suse.com
- updated to 2.5.0
  - match libgphoto2 2.5.0 api release
* Sun Apr 15 2012 meissner@suse.de
- updated to 2.4.14
  - --list-all-config
  - translation updates
  - small bugfixes
* Sat Dec 10 2011 meissner@suse.de
- Updated to 2.4.11.1 temp snapshot
  - aalib disabled by default
  - linker issue fixed
  - some translation updates
  - bugfixes
* Tue Apr 19 2011 meissner@suse.de
- Updated to 2.4.11
  - minor bugfixes
  - translation updates
* Sun Aug 15 2010 meissner@suse.de
- Updated to 2.4.10
  - --capture-movie added
  - event handling fixed
  - translations
* Fri Jun 18 2010 meissner@suse.de
- merge over the wait event loop fix from the branch.
* Sun Apr 11 2010 meissner@suse.de
- Updated to 2.4.9 final
  - Capture main event loop rewritten to always use wait event
  to also support multiple image captures. (JPEG+RAW)
  - Fixed various bugs and memory leaks.
  - Translation updates.
* Mon Jan 25 2010 meissner@suse.de
- updated to 2.4.8 final
  - added CAPTURECOMPLETE event
  - --bulb / -B addable for interval
  - added readonly widget support
  - translation updates
* Fri Aug 21 2009 meissner@suse.de
- updated to 2.4.7 final
  - fixed --port selection bug
  - proper COPYING file (this package is GPL v2 and later)
* Mon Jul 27 2009 meissner@suse.de
- updated to 2.4.5.2 temp snapshot
  - wait-event now with second wait time
  - added wait-event and wait-event-and-download and capture-tethered
  to shell mode.
* Thu Jun 25 2009 meissner@suse.de
- updated to 2.4.5.1 temp snapshot
  - 4GB files now possible (instead of 2GB limit)
  - --set-config-index and --set-config-value
  - save files based on umask
* Thu Apr  2 2009 meissner@suse.de
- updated to 2.4.5 release
  * fixed ctrl-c handling in tethered capture
  * translation updates
* Thu Jan 22 2009 meissner@suse.de
- upgraded to 2.4.4 release
  * SIGUSR2 termination of interval capture
  * translation updates
* Sun Oct 19 2008 meissner@suse.de
- upgraded to 2.4.3 release
  * --port usb:XXX,YYY is now sufficient to specify
  one of multiple cameras
* Sun Jul 13 2008 meissner@suse.de
- upgraded to 2.4.2 release
  * translation updates
  * --capture-image split into --capture-image and
  - -capture-image-and-download
* Fri Mar 28 2008 meissner@suse.de
- upgraded to 2.4.1 release
  * Made capture preview that saves to files work
  * capture-image has no arguments
  * version check for libgphoto2 fixed
  * cs,da,it,vi translations updated
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro.
* Mon Jul 30 2007 meissner@suse.de
- upgrade to 2.4.0 final (only minimal other changes)
* Wed Jan 10 2007 meissner@suse.de
- Upgraded to current TRUNK version.
  - uses the new download features, no longer
  needs sizeof(IMAGE) memory.
  - new --storage-info option.
* Tue Dec  5 2006 meissner@suse.de
- upgraded to 2.3.0 final
  - small fixes only
* Sat Oct 21 2006 meissner@suse.de
- buildrequires libgphoto2-devel
* Tue Oct 17 2006 meissner@suse.de
- Upgraded to 2.2.1.4.trunk
  - moving headers around mostly.
* Wed Sep 27 2006 meissner@suse.de
- Upgraded to 2.2.0.2.trunk
  - option handling changed to use popt exclusively
  - shell fixes mostly (rmdir, cd)
  - bugfixes
* Mon Jun 19 2006 meissner@suse.de
- Upgraded to 2.2.0 release.
  - More shell commands (mkdir,put,*config)
  - -u *.ogg *.mp3 for MTP devices
  - Meta data support for MTP
  - Wait for event handling
  - Translation updates
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jul 12 2005 meissner@suse.de
- Upgraded to current 2.1.99head development branch.
  - builds with libgphoto 2.1.99 branch.
* Fri Feb  4 2005 meissner@suse.de
- Upgraded to current 2.1.6 development branch.
  - property set support
* Thu Dec 16 2004 meissner@suse.de
- Upgraded to 2.1.5:
  - property list and get support
* Mon Oct 18 2004 ro@suse.de
- locale rename: no -> nb
* Fri Jul 30 2004 meissner@suse.de
- Upgraded to current HEAD branch.
  - work with libexif 0.6.10
  - more translations.
  - timelapsed capture support.
  - bugfixes.
* Mon Jan 19 2004 meissner@suse.de
- Upgraded to 2.1.4 release:
  - bugfixes, translations, some small new features.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep 15 2003 meissner@suse.de
- Added hungarian translation from Peter Varkoly.
* Tue Aug 12 2003 meissner@suse.de
- Upgraded to 2.1.2 release. (Not much changes inside).
* Tue May 13 2003 meissner@suse.de
- Upgraded to current CVS version.
- Package missing manpage.
* Tue Dec  3 2002 meissner@suse.de
- Upgraded to final 2.1.1 version.
* Mon Nov 18 2002 meissner@suse.de
- Upgraded to 2.1.1rc1 release candidate snapshot.
  - popt option handling.
  - Lots of bugfixes.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jul 29 2002 meissner@suse.de
- splitted away libgphoto2, updated to latest upstream.
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Tue Jul  2 2002 meissner@suse.de
- Upgraded to 2.1.0 release, removed fPIC hack.
* Tue Jun 25 2002 uli@suse.de
- build libgphoto2_port.a with -fPIC
* Wed Jun 19 2002 meissner@suse.de
- Upgraded to upstream 2.1.0rc2 (translation changes only)
- Do not link against libreadline in the camera libraries.
* Tue Jun 18 2002 meissner@suse.de
- Upgraded to upstream 2.1.0rc1:
  * support for periodic keep-alive-messages
  * support for Canon EOS D60, Canon PowerShot A40, Canon PowerShot A30,
    Canon PowerShot S200, Canon Digital IXUS 330,
    Canon PowerShot S10 (fixed it)
  * Added SiPix Web2 support.
* Wed Apr  3 2002 meissner@suse.de
- Upgraded to current development snapshot.
  - PTP camera support enhanced, bugfixes and enhancements in others.
  - Fixed automake/autoconf problems.
  - Started to enable documentation building.
* Mon Feb 25 2002 meissner@suse.de
- Upgraded to 2.0 final, contains:
  - Svensk translation
  - Several fixes for bugs found during release candidate testing
  - Documentation updates.
  - Some fixes in the build / Makefile structure.
* Thu Feb 14 2002 meissner@suse.de
- do not call gphoto in %%post, use a static list for now.
- compile without static libraries, we do not use them anyway.
* Wed Feb 13 2002 meissner@suse.de
- Usb agent added that chowns the device to the logged in user,
  so users can use USB Digital Cameras without any need for setuid
  wrappers. (Modified usb.usermap in post/postun of package)
- added a patch to make digikam compile with the headers
* Mon Feb 11 2002 meissner@suse.de
- Upgraded to beta5, lib64 patch is now included already in upstream source.
* Fri Jan 25 2002 meissner@suse.de
- lib64 patches to fix s390x build
* Tue Jan 22 2002 ro@suse.de
- help libtool with RPM_BUILD_ROOT by exporting LIBRARY_PATH
* Mon Jan 21 2002 meissner@suse.de
- update -> 2.0beta4dev9 (needs newer libusb)
- moved from /opt/gnome back to /usr since gphoto2 is just a library,
  without GUI components.
- removed bugbuddy requirement, this was a gphoto 0.4.3ism.
* Fri Dec  7 2001 uli@suse.de
- update -> 2.0beta3
* Mon Nov 19 2001 uli@suse.de
- moved to /opt/gnome, added req. on bug-buddy (bug #11523)
- bzipped tarball
* Mon Jul  2 2001 uli@suse.de
- disabled RT scheduling (may hang machine)
* Wed Jun 27 2001 schwab@suse.de
- Fix strcat calls.
* Tue Apr 17 2001 uli@suse.de
- 64 bit fixes for some backends
* Thu Mar  1 2001 egger@suse.de
- Major overhaul. Use BuildRooting, RPM_OPT_FLAGS and
  cleaned up specfile a lot.
* Sun Feb 25 2001 egger@suse.de
- Remove unnecessary dependencies from #neededforbuild,
  especially imlib-config.
* Tue Jan 30 2001 ro@suse.de
- changed neededforbuild <imlibcfe> to <imlib-config>
* Sat Jan 27 2001 violiet@suse.de
- added gphoto call gtk_set_locale() _BEFORE_ gtk_init().
* Thu Nov 30 2000 ro@suse.de
- fixed neededforbuild
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Tue Jun  6 2000 uli@suse.de
- update -> 0.4.3
- moved docs to %%{_docdir}
* Sat Apr  8 2000 bk@suse.de
- added suse update config macro
* Wed Mar  1 2000 uli@suse.de
- moved man page to /usr/share
* Fri Jan 14 2000 uli@suse.de
- New version 0.4.2
* Thu Oct  7 1999 uli@suse.de
- New version 0.4.0
* Tue Sep 28 1999 uli@suse.de
- New version 0.3.9
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Thu Jul  8 1999 uli@suse.de
- New version 0.3.4
* Wed Jun 23 1999 uli@suse.de
- Spec file created from gphoto-0.3.2.tar.gz by autospec
